==> TencentNavKitDocument_7.1.1.zip: TencentNavKitDocument/search/properties_12.js <==
var searchData=
[
  ['text_0',['text',['../interface_t_n_k_audio_param.html#a7f4b82528d884bcbdfb7f9d7f1a51f78',1,'TNKAudioParam']]],
  ['timedesc_1',['timeDesc',['../interface_t_n_k_turn_restriction_item.html#ace2cec70570e9139d4ad649baddf241a',1,'TNKTurnRestrictionItem']]],
  ['tipsremainingdistance_2',['tipsRemainingDistance',['../interface_t_n_k_drive_navigation_data.html#a8c96efcd658c33d9064b64c6dce3f345',1,'TNKDriveNavigationData']]],
  ['tipstext_3',['tipsText',['../interface_t_n_k_drive_navigation_data.html#a35036fcb2160bab0fa0f097721d7f9b5',1,'TNKDriveNavigationData']]],
  ['title_4',['title',['../interface_t_n_k_search_nav_point.html#a31f036565e479f0aaa46a47b6a90ea0b',1,'TNKSearchNavPoint']]],
  ['to_5',['to',['../interface_t_n_k_drive_route_explain.html#a23f211ac32ee397d3489271a065f6c12',1,'TNKDriveRouteExplain::to()'],['../interface_t_n_k_route_traffic_item.html#ae4f1f434cff41e82ebcf9fc42dd9efca',1,'TNKRouteTrafficItem::to()'],['../interface_t_n_k_segment_road_name.html#aa4c1082afc56c0703bd19fe5217f8ef9',1,'TNKSegmentRoadName::to()'],['../interface_t_n_k_segment_item.html#aa469294dcd2b4a7f64967999d24b23e3',1,'TNKSegmentItem::to()']]],
  ['tolldistance_6',['tollDistance',['../interface_t_n_k_drive_route.html#ac90519bc24b33ccadc17f159741447dd',1,'TNKDriveRoute']]],
  ['tollstationitems_7',['tollStationItems',['../interface_t_n_k_toll_station_info.html#a99911cd9b517c2fb26561b44b320eae7',1,'TNKTollStationInfo']]],
  ['topleftcornerradius_8',['topLeftCornerRadius',['../interface_t_n_k_enlarged_map_config.html#aaca98a000dcfd22ca5d5d89d2c70e59c',1,'TNKEnlargedMapConfig']]],
  ['toprightcornerradius_9',['topRightCornerRadius',['../interface_t_n_k_enlarged_map_config.html#a23c588befb5a95d626df0cede2c259a3',1,'TNKEnlargedMapConfig']]],
  ['totaldistance_10',['totalDistance',['../interface_t_n_k_drive_route.html#ae783ff13a91ed6ac8ab3fcc525812a35',1,'TNKDriveRoute::totalDistance()'],['../interface_t_n_k_ride_route.html#ac2dee87ab58485b006536314e5adbc1f',1,'TNKRideRoute::totalDistance()'],['../interface_t_n_k_walk_route.html#abbe8a876b0746c3b4ec48ba2608208c7',1,'TNKWalkRoute::totalDistance()']]],
  ['totaldistanceleft_11',['totalDistanceLeft',['../interface_t_n_k_drive_navigation_data.html#ae4f56809abe4569aa5bf4ba0217071a6',1,'TNKDriveNavigationData::totalDistanceLeft()'],['../interface_t_n_k_ride_navigation_data.html#a03b6f1a6d3c21c1b5e6a6bf00f64ce8b',1,'TNKRideNavigationData::totalDistanceLeft()'],['../interface_t_n_k_walk_navigation_data.html#a06c65c19424fdd24c3144f4edb69db84',1,'TNKWalkNavigationData::totalDistanceLeft()']]],
  ['totaltime_12',['totalTime',['../interface_t_n_k_drive_route.html#a937924f395281c6796eb8e73414e9eb6',1,'TNKDriveRoute::totalTime()'],['../interface_t_n_k_ride_route.html#af64f673cc90cbc6ded6f2da6f2100020',1,'TNKRideRoute::totalTime()'],['../interface_t_n_k_walk_route.html#a59ec5e382710ba98c6865866d2b8d720',1,'TNKWalkRoute::totalTime()']]],
  ['totaltimeleft_13',['totalTimeLeft',['../interface_t_n_k_drive_navigation_data.html#a72cfa962357a9b87a97011d88341a31f',1,'TNKDriveNavigationData::totalTimeLeft()'],['../interface_t_n_k_ride_navigation_data.html#a13789ebade7dfed0f9c4ec889c104698',1,'TNKRideNavigationData::totalTimeLeft()'],['../interface_t_n_k_walk_navigation_data.html#a6affa1ca29a6c85fe1bfe988b8b92071',1,'TNKWalkNavigationData::totalTimeLeft()']]],
  ['trafficbar_14',['trafficBar',['../interface_t_n_k_drive_nav_view.html#aeb2d29a923ee9fdc088b3e5108cb9ec0',1,'TNKDriveNavView']]],
  ['trafficbubbleenabled_15',['trafficBubbleEnabled',['../interface_t_n_k_drive_nav_view.html#a6728c9a424db606920c2693b437d50cb',1,'TNKDriveNavView']]],
  ['trafficlightcount_16',['trafficLightCount',['../interface_t_n_k_drive_route.html#ab1e9f2fcc85f296622ee7becb6081cbd',1,'TNKDriveRoute::trafficLightCount()'],['../interface_t_n_k_ride_route.html#a7f920251b0e6f79214b16e2bd6b02a79',1,'TNKRideRoute::trafficLightCount()'],['../interface_t_n_k_segment_item.html#a74f12490ed11cfb394221369b023c658',1,'TNKSegmentItem::trafficLightCount()'],['../interface_t_n_k_walk_route.html#af1dbe672edc6a9333a292663a4dfd850',1,'TNKWalkRoute::trafficLightCount()']]],
  ['trafficlights_17',['trafficLights',['../interface_t_n_k_drive_route.html#af72f2dc7b87e6b01379166fc05dcb5cb',1,'TNKDriveRoute']]],
  ['trafficlighttype_18',['trafficLightType',['../interface_t_n_k_traffic_light_countdown_msg.html#a71effb68e4fbcc8bec01da71a1269b73',1,'TNKTrafficLightCountdownMsg']]],
  ['trafficstatus_19',['trafficStatus',['../interface_t_n_k_route_traffic_item.html#aab116c856127c415b4258225e50fe7ef',1,'TNKRouteTrafficItem::trafficStatus()'],['../interface_t_n_k_traffic_jam_info.html#a06ade147dbe58760cb7f30d41c9fdc47',1,'TNKTrafficJamInfo::trafficStatus()']]],
  ['trailertype_20',['trailerType',['../interface_t_n_k_truck_search_option.html#ae272dc12969ef8feebeb3bd7937d13f6',1,'TNKTruckSearchOption']]],
  ['trucknavrestrictionitems_21',['truckNavRestrictionItems',['../interface_t_n_k_nav_restriction_info.html#aecfcfaf6dd303e147bf93119ee1198c0',1,'TNKNavRestrictionInfo']]],
  ['truckrestrictionitem_22',['truckRestrictionItem',['../interface_t_n_k_truck_nav_restriction_item.html#a04ecec061141d1c08f4dbf2594632bff',1,'TNKTruckNavRestrictionItem']]],
  ['truckrestrictionitems_23',['truckRestrictionItems',['../interface_t_n_k_drive_route.html#ab8ca7bf37b9c16c2bea6e0d1540c91ae',1,'TNKDriveRoute']]],
  ['trucksearchoption_24',['truckSearchOption',['../interface_t_n_k_drive_route_search_option.html#a8da36d2feefe574f560b74b11f3f0118',1,'TNKDriveRouteSearchOption']]],
  ['trucktype_25',['truckType',['../interface_t_n_k_truck_search_option.html#acafbfbae9f524be142ab7bb4c3a919c2',1,'TNKTruckSearchOption']]],
  ['ttsmode_26',['ttsMode',['../interface_t_n_k_drive_nav_manager.html#a50179ae9c54a45b3028482e8c07ecf19',1,'TNKDriveNavManager']]],
  ['ttsstring_27',['ttsString',['../interface_t_n_k_nav_t_t_s.html#a5db6dc30082841bd61b7cbe63666cd18',1,'TNKNavTTS']]],
  ['turnarrowconfig_28',['turnArrowConfig',['../interface_t_n_k_base_nav_view.html#abbf9b3753705fbb2dc2ead2ecdc8d892',1,'TNKBaseNavView']]],
  ['turnarrowenabled_29',['turnArrowEnabled',['../interface_t_n_k_base_nav_view.html#a23bf3cafd5fe813e42a698964d8cf5ea',1,'TNKBaseNavView']]],
  ['turnnavrestrictionitems_30',['turnNavRestrictionItems',['../interface_t_n_k_nav_restriction_info.html#a2d9ff3c30305f569c059a3c93da3c781',1,'TNKNavRestrictionInfo']]],
  ['turnrestrictionitem_31',['turnRestrictionItem',['../interface_t_n_k_turn_nav_restriction_item.html#a2ff38a3c7a873bfc6735e11d9b7b2be0',1,'TNKTurnNavRestrictionItem']]],
  ['turnrestrictionitems_32',['turnRestrictionItems',['../interface_t_n_k_drive_route.html#ad91bc2d4e846f800acadae73ab1b335f',1,'TNKDriveRoute']]],
  ['type_33',['type',['../interface_t_n_k_nav_camera_info.html#a0d970991a4ad4f1f6a1d6f57a3253546',1,'TNKNavCameraInfo::type()'],['../interface_t_n_k_truck_restriction_item.html#a2e70157ea76d9941a3c7f6eccad5a255',1,'TNKTruckRestrictionItem::type()'],['../interface_t_n_k_turn_restriction_item.html#a9ce12e9a90bd3f7adbbe0983eee5055f',1,'TNKTurnRestrictionItem::type()'],['../interface_t_n_k_drive_route_explain.html#aa08bc46af135f95d7526473af07ce925',1,'TNKDriveRouteExplain::type()'],['../interface_t_n_k_highway_facility_item.html#a482476198a13ef51c38e42da03869bce',1,'TNKHighwayFacilityItem::type()'],['../interface_t_n_k_location_listener_config.html#acfa16ab5cfdef2da6febcf5a6878554c',1,'TNKLocationListenerConfig::type()'],['../interface_t_n_k_nav_t_t_s.html#a6fe2234a971c6fde0f1ce63519cf881d',1,'TNKNavTTS::type()']]]
];

==> TencentNavKitDocument_7.2.1.zip: TencentNavKitDocument/search/properties_12.js <==
var searchData=
[
  ['text_0',['text',['../interface_t_n_k_audio_param.html#a7f4b82528d884bcbdfb7f9d7f1a51f78',1,'TNKAudioParam']]],
  ['timedesc_1',['timeDesc',['../interface_t_n_k_turn_restriction_item.html#ace2cec70570e9139d4ad649baddf241a',1,'TNKTurnRestrictionItem']]],
  ['tipsremainingdistance_2',['tipsRemainingDistance',['../interface_t_n_k_drive_navigation_data.html#a8c96efcd658c33d9064b64c6dce3f345',1,'TNKDriveNavigationData::tipsRemainingDistance()'],['../interface_t_n_k_travel_navigation_data.html#acdc7debfb829a5e9d9421b0eb5acacd3',1,'TNKTravelNavigationData::tipsRemainingDistance()']]],
  ['tipstext_3',['tipsText',['../interface_t_n_k_drive_navigation_data.html#a35036fcb2160bab0fa0f097721d7f9b5',1,'TNKDriveNavigationData::tipsText()'],['../interface_t_n_k_travel_navigation_data.html#a1be88728e3fa833c7e18e8c7ef9a38c3',1,'TNKTravelNavigationData::tipsText()']]],
  ['title_4',['title',['../interface_t_n_k_search_nav_point.html#a31f036565e479f0aaa46a47b6a90ea0b',1,'TNKSearchNavPoint']]],
  ['to_5',['to',['../interface_t_n_k_drive_route_explain.html#a23f211ac32ee397d3489271a065f6c12',1,'TNKDriveRouteExplain::to()'],['../interface_t_n_k_route_traffic_item.html#ae4f1f434cff41e82ebcf9fc42dd9efca',1,'TNKRouteTrafficItem::to()'],['../interface_t_n_k_segment_road_name.html#aa4c1082afc56c0703bd19fe5217f8ef9',1,'TNKSegmentRoadName::to()'],['../interface_t_n_k_segment_item.html#aa469294dcd2b4a7f64967999d24b23e3',1,'TNKSegmentItem::to()']]],
  ['tolldistance_6',['tollDistance',['../interface_t_n_k_drive_route.html#ac90519bc24b33ccadc17f159741447dd',1,'TNKDriveRoute']]],
  ['tollstationitems_7',['tollStationItems',['../interface_t_n_k_toll_station_info.html#a99911cd9b517c2fb26561b44b320eae7',1,'TNKTollStationInfo']]],
  ['topleftcornerradius_8',['topLeftCornerRadius',['../interface_t_n_k_enlarged_map_config.html#aaca98a000dcfd22ca5d5d89d2c70e59c',1,'TNKEnlargedMapConfig']]],
  ['toprightcornerradius_9',['topRightCornerRadius',['../interface_t_n_k_enlarged_map_config.html#a23c588befb5a95d626df0cede2c259a3',1,'TNKEnlargedMapConfig']]],
  ['totaldistance_10',['totalDistance',['../interface_t_n_k_drive_route.html#ae783ff13a91ed6ac8ab3fcc525812a35',1,'TNKDriveRoute::totalDistance()'],['../interface_t_n_k_ride_route.html#ac2dee87ab58485b006536314e5adbc1f',1,'TNKRideRoute::totalDistance()'],['../interface_t_n_k_walk_route.html#abbe8a876b0746c3b4ec48ba2608208c7',1,'TNKWalkRoute::totalDistance()']]],
  ['totaldistanceleft_11',['totalDistanceLeft',['../interface_t_n_k_drive_navigation_data.html#ae4f56809abe4569aa5bf4ba0217071a6',1,'TNKDriveNavigationData::totalDistanceLeft()'],['../interface_t_n_k_ride_navigation_data.html#a03b6f1a6d3c21c1b5e6a6bf00f64ce8b',1,'TNKRideNavigationData::totalDistanceLeft()'],['../interface_t_n_k_travel_navigation_data.html#a116181d272213eb32e39df35b7520e6e',1,'TNKTravelNavigationData::totalDistanceLeft()'],['../interface_t_n_k_walk_navigation_data.html#a06c65c19424fdd24c3144f4edb69db84',1,'TNKWalkNavigationData::totalDistanceLeft()']]],
  ['totaltime_12',['totalTime',['../interface_t_n_k_drive_route.html#a937924f395281c6796eb8e73414e9eb6',1,'TNKDriveRoute::totalTime()'],['../interface_t_n_k_ride_route.html#af64f673cc90cbc6ded6f2da6f2100020',1,'TNKRideRoute::totalTime()'],['../interface_t_n_k_walk_route.html#a59ec5e382710ba98c6865866d2b8d720',1,'TNKWalkRoute::totalTime()']]],
  ['totaltimeleft_13',['totalTimeLeft',['../interface_t_n_k_drive_navigation_data.html#a72cfa962357a9b87a97011d88341a31f',1,'TNKDriveNavigationData::totalTimeLeft()'],['../interface_t_n_k_ride_navigation_data.html#a13789ebade7dfed0f9c4ec889c104698',1,'TNKRideNavigationData::totalTimeLeft()'],['../interface_t_n_k_travel_navigation_data.html#a4125b6bc5994d3217386bb10bfe1a3f1',1,'TNKTravelNavigationData::totalTimeLeft()'],['../interface_t_n_k_walk_navigation_data.html#a6affa1ca29a6c85fe1bfe988b8b92071',1,'TNKWalkNavigationData::totalTimeLeft()']]],
  ['trafficbar_14',['trafficBar',['../interface_t_n_k_drive_nav_view.html#aeb2d29a923ee9fdc088b3e5108cb9ec0',1,'TNKDriveNavView::trafficBar()'],['../interface_t_n_k_travel_nav_view.html#adc8c1c070bab2833561231c819597508',1,'TNKTravelNavView::trafficBar()']]],
  ['trafficbubbleenabled_15',['trafficBubbleEnabled',['../interface_t_n_k_drive_nav_view.html#a6728c9a424db606920c2693b437d50cb',1,'TNKDriveNavView::trafficBubbleEnabled()'],['../interface_t_n_k_travel_nav_view.html#acef6afd156b3bf292c82d80efdc1e5bf',1,'TNKTravelNavView::trafficBubbleEnabled()']]],
  ['trafficlightcount_16',['trafficLightCount',['../interface_t_n_k_drive_route.html#ab1e9f2fcc85f296622ee7becb6081cbd',1,'TNKDriveRoute::trafficLightCount()'],['../interface_t_n_k_ride_route.html#a7f920251b0e6f79214b16e2bd6b02a79',1,'TNKRideRoute::trafficLightCount()'],['../interface_t_n_k_segment_item.html#a74f12490ed11cfb394221369b023c658',1,'TNKSegmentItem::trafficLightCount()'],['../interface_t_n_k_walk_route.html#af1dbe672edc6a9333a292663a4dfd850',1,'TNKWalkRoute::trafficLightCount()']]],
  ['trafficlights_17',['trafficLights',['../interface_t_n_k_drive_route.html#af72f2dc7b87e6b01379166fc05dcb5cb',1,'TNKDriveRoute']]],
  ['trafficlighttype_18',['trafficLightType',['../interface_t_n_k_traffic_light_countdown_msg.html#a71effb68e4fbcc8bec01da71a1269b73',1,'TNKTrafficLightCountdownMsg']]],
  ['trafficstatus_19',['trafficStatus',['../interface_t_n_k_route_traffic_item.html#aab116c856127c415b4258225e50fe7ef',1,'TNKRouteTrafficItem::trafficStatus()'],['../interface_t_n_k_traffic_jam_info.html#a06ade147dbe58760cb7f30d41c9fdc47',1,'TNKTrafficJamInfo::trafficStatus()']]],
  ['trailertype_20',['trailerType',['../interface_t_n_k_truck_search_option.html#ae272dc12969ef8feebeb3bd7937d13f6',1,'TNKTruckSearchOption']]],
  ['trucknavrestrictionitems_21',['truckNavRestrictionItems',['../interface_t_n_k_nav_restriction_info.html#aecfcfaf6dd303e147bf93119ee1198c0',1,'TNKNavRestrictionInfo']]],
  ['truckrestrictionitem_22',['truckRestrictionItem',['../interface_t_n_k_truck_nav_restriction_item.html#a04ecec061141d1c08f4dbf2594632bff',1,'TNKTruckNavRestrictionItem']]],
  ['truckrestrictionitems_23',['truckRestrictionItems',['../interface_t_n_k_drive_route.html#ab8ca7bf37b9c16c2bea6e0d1540c91ae',1,'TNKDriveRoute']]],
  ['trucksearchoption_24',['truckSearchOption',['../interface_t_n_k_drive_route_search_option.html#a8da36d2feefe574f560b74b11f3f0118',1,'TNKDriveRouteSearchOption']]],
  ['trucktype_25',['truckType',['../interface_t_n_k_truck_search_option.html#acafbfbae9f524be142ab7bb4c3a919c2',1,'TNKTruckSearchOption']]],
  ['ttsmode_26',['ttsMode',['../interface_t_n_k_drive_nav_manager.html#a50179ae9c54a45b3028482e8c07ecf19',1,'TNKDriveNavManager::ttsMode()'],['../interface_t_n_k_ride_nav_manager.html#ac379a1a6c16797aca862e4f9e67c8c78',1,'TNKRideNavManager::ttsMode()'],['../interface_t_n_k_walk_nav_manager.html#aa77fef25d05aff642a34c04581ada1ca',1,'TNKWalkNavManager::ttsMode()']]],
  ['ttsstring_27',['ttsString',['../interface_t_n_k_nav_t_t_s.html#a5db6dc30082841bd61b7cbe63666cd18',1,'TNKNavTTS']]],
  ['turnarrowconfig_28',['turnArrowConfig',['../interface_t_n_k_base_nav_view.html#abbf9b3753705fbb2dc2ead2ecdc8d892',1,'TNKBaseNavView']]],
  ['turnarrowenabled_29',['turnArrowEnabled',['../interface_t_n_k_base_nav_view.html#a23bf3cafd5fe813e42a698964d8cf5ea',1,'TNKBaseNavView']]],
  ['turnnavrestrictionitems_30',['turnNavRestrictionItems',['../interface_t_n_k_nav_restriction_info.html#a2d9ff3c30305f569c059a3c93da3c781',1,'TNKNavRestrictionInfo']]],
  ['turnrestrictionitem_31',['turnRestrictionItem',['../interface_t_n_k_turn_nav_restriction_item.html#a2ff38a3c7a873bfc6735e11d9b7b2be0',1,'TNKTurnNavRestrictionItem']]],
  ['turnrestrictionitems_32',['turnRestrictionItems',['../interface_t_n_k_drive_route.html#ad91bc2d4e846f800acadae73ab1b335f',1,'TNKDriveRoute']]],
  ['type_33',['type',['../interface_t_n_k_nav_camera_info.html#a0d970991a4ad4f1f6a1d6f57a3253546',1,'TNKNavCameraInfo::type()'],['../interface_t_n_k_truck_restriction_item.html#a2e70157ea76d9941a3c7f6eccad5a255',1,'TNKTruckRestrictionItem::type()'],['../interface_t_n_k_turn_restriction_item.html#a9ce12e9a90bd3f7adbbe0983eee5055f',1,'TNKTurnRestrictionItem::type()'],['../interface_t_n_k_drive_route_explain.html#aa08bc46af135f95d7526473af07ce925',1,'TNKDriveRouteExplain::type()'],['../interface_t_n_k_highway_facility_item.html#a482476198a13ef51c38e42da03869bce',1,'TNKHighwayFacilityItem::type()'],['../interface_t_n_k_location_listener_config.html#acfa16ab5cfdef2da6febcf5a6878554c',1,'TNKLocationListenerConfig::type()'],['../interface_t_n_k_nav_t_t_s.html#a6fe2234a971c6fde0f1ce63519cf881d',1,'TNKNavTTS::type()']]]
];
